{
    'name': "Password Policy",
    "summary": "Implement basic password policy configuration & check",
    'category': 'Tools',
    'depends': ['base_setup', 'web'],
    'data': [
        'data/defaults.xml',
        'views/assets.xml',
        'views/res_users.xml',
        'views/res_config_settings_views.xml',
    ]
}
